# evo_django_kits

[![CI](https://github.com/maycuatroi/evo-django-kits/actions/workflows/main.yml/badge.svg)](https://github.com/maycuatroi/evo-django-kits/actions/workflows/main.yml)
[![PyPI version](https://badge.fury.io/py/evo-django-kits.svg)](https://badge.fury.io/py/evo-django-kits)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/evo-django-kits)](https://pypi.org/project/evo-django-kits/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/evo-django-kits)](https://pypi.org/project/evo-django-kits/)
[![PyPI - License](https://img.shields.io/pypi/l/evo-django-kits)](https://pypi.org/project/evo-django-kits/)
[![GitHub issues](https://img.shields.io/github/issues/maycuatroi/evo-django-kits)](
https://github.com/maycuatroi/evo-django-kits/issues
)

Awesome evo_django_kits created by maycuatroi

## Install it from PyPI

```bash
pip install evo-django-kits
```

## Usage

```py
from evo_django_kits import BaseClass
from evo_django_kits import base_function

BaseClass().base_method()
base_function()
```

```bash
$ python -m evo_django_kits
#or
$ evo_django_kits
```

## Development

Read the [CONTRIBUTING.md](CONTRIBUTING.md) file.
